==> halkyon-annotations-0.8.2.redhat-00001-sources.jar: io/dekorate/halkyon/model/LinkListFluent.java <==
package io.dekorate.halkyon.model;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.deps.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Fluent;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.deps.javax.validation.constraints.NotNull;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import io.dekorate.deps.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import io.dekorate.deps.javax.validation.Valid;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface LinkListFluent<A extends LinkListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Link item);
    public A setToItems(int index,Link item);
    public A addToItems(Link... items);
    public A addAllToItems(Collection<Link> items);
    public A removeFromItems(Link... items);
    public A removeAllFromItems(Collection<Link> items);
    public A removeMatchingFromItems(Predicate<LinkBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<Link> getItems();
    public java.util.List<Link> buildItems();
    public Link buildItem(int index);
    public Link buildFirstItem();
    public Link buildLastItem();
    public Link buildMatchingItem(Predicate<LinkBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<LinkBuilder> predicate);
    public A withItems(java.util.List<Link> items);
    public A withItems(Link... items);
    public Boolean hasItems();
    public LinkListFluent.ItemsNested<A> addNewItem();
    public LinkListFluent.ItemsNested<A> addNewItemLike(Link item);
    public LinkListFluent.ItemsNested<A> setNewItemLike(int index,Link item);
    public LinkListFluent.ItemsNested<A> editItem(int index);
    public LinkListFluent.ItemsNested<A> editFirstItem();
    public LinkListFluent.ItemsNested<A> editLastItem();
    public LinkListFluent.ItemsNested<A> editMatchingItem(Predicate<LinkBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,LinkFluent<LinkListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> halkyon-annotations-0.10.10.redhat-00001-sources.jar: io/dekorate/halkyon/model/LinkListFluent.java <==
package io.dekorate.halkyon.model;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.deps.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Fluent;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import io.dekorate.deps.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface LinkListFluent<A extends LinkListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Link item);
    public A setToItems(int index,Link item);
    public A addToItems(Link... items);
    public A addAllToItems(Collection<Link> items);
    public A removeFromItems(Link... items);
    public A removeAllFromItems(Collection<Link> items);
    public A removeMatchingFromItems(Predicate<LinkBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Link> getItems();
    public List<Link> buildItems();
    public Link buildItem(int index);
    public Link buildFirstItem();
    public Link buildLastItem();
    public Link buildMatchingItem(Predicate<LinkBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<LinkBuilder> predicate);
    public A withItems(List<Link> items);
    public A withItems(Link... items);
    public Boolean hasItems();
    public LinkListFluent.ItemsNested<A> addNewItem();
    public LinkListFluent.ItemsNested<A> addNewItemLike(Link item);
    public LinkListFluent.ItemsNested<A> setNewItemLike(int index,Link item);
    public LinkListFluent.ItemsNested<A> editItem(int index);
    public LinkListFluent.ItemsNested<A> editFirstItem();
    public LinkListFluent.ItemsNested<A> editLastItem();
    public LinkListFluent.ItemsNested<A> editMatchingItem(Predicate<LinkBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,LinkFluent<LinkListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
